/*
' Name:					fn_admissions_curricula()
' Description:			This function finds differences between sorlcur / fos and srbrecr / saradap
'
'							sorlcur:
'								dept_code	-- department
'								majr_code	-- major
'								minr_code	-- minor
'								conc_code	-- concentration
'
'							sorlfos:
'								coll_code	-- college
'								levl_code	-- level
'								degc_code	-- degree
'								admt_code	-- admit_type
'								styp_code	-- student_type
'								camp_code	-- campus
'
'							Rules:
'								1.	always take recruit people, do NOT include people in admissions (saradap) that are not in recruiting (srbrecr).
'								2.	admissions (saradap) takes precedence over rucruit (srbrecr), if there is an admissions record,
'									use it, otherwise use recruiting
'								3.	joins to sorlcur
'										a. srbrecr -> admin_seqno = sorlcur_key_seqno
'										b. saradap -> appl_no = key_seqno
'								4.	lowest priority, highest seqno on that priority is primary record we want from sorlcur
'								5.	join with sorlfos using pidm / term / priority / sorlcur_seqno = fos.lcur_seqno
'									using the lowest priority number, highest seqno in sorlfos
'								6. when pulling sorlfos_depart_code, where sorlfos_lfst_code = 'MAJOR'
'
' Creator:				Dan Rickner && Ben Roller
' Create Date:			October 09, 2008
' ------------------------------------------------------------------------------
' Modification Date:		January 14, 2010
' Modified by:			Benjamin Roller
' Change Log:		1.	Converted to clover
' ------------------------------------------------------------------------------
' Modification Date:	
' Modified by:			
' Change Log:		1. 
' ------------------------------------------------------------------------------
*/

if exists (select 1 from information_schema.tables where table_name = 'fn_admissions_curricula_dump')
drop table [dbo].[fn_admissions_curricula_dump];

/*
	Rules:
		1.	always take recruit records, even if no admissions exists
				(right outer join to recruit at bottom)
		2. if admissions does exist, then take it's information
				(case statement here at top)
		3.	always pull appl_no and admin_seqno regardless of what type of record it is
			Since a recruit must exist for an admissions to exist, the recruit admin_seqno will never be null and
			you can join on that field back to srbrecr without needing to get sorlcur involved for levl and coll_code.
			(fact_admissions: fn_apdc_codes1() does this)
*/

	select
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.saradap_pidm  else RECRUIT.srbrecr_pidm	 end as pidm,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.term_code		 else RECRUIT.term_code		 end as term_code,
		isnull(ADMISSIONS.appl_no, 0)  as appl_no,		-- may be null if no admissions record
		RECRUIT.admin_seqno as admin_seqno,	-- should never be null
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.appl_no		 else RECRUIT.admin_seqno	 end as sequence_number,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.coll_code		 else RECRUIT.coll_code		 end as coll_code,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.styp_code		 else RECRUIT.styp_code		 end as styp_code,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.levl_code		 else RECRUIT.levl_code		 end as levl_code,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.camp_code		 else RECRUIT.camp_code		 end as camp_code,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.admt_code		 else RECRUIT.admt_code		 end as admt_code,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.rtyp_code		 else RECRUIT.rtyp_code		 end as rtyp_code,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.resd_code		 else RECRUIT.resd_code		 end as resd_code,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.dept_code		 else RECRUIT.dept_code		 end as dept_code,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.degc_code		 else RECRUIT.degc_code		 end as degc_code,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.majr_code		 else RECRUIT.majr_code		 end as majr_code,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.majr2_code	 else RECRUIT.majr2_code	 end as majr2_code,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.minr_code		 else RECRUIT.minr_code		 end as minr_code,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.conc_code		 else RECRUIT.conc_code		 end as conc_code,
		case when ADMISSIONS.saradap_pidm is not null then isnull(ADMISSIONS.recr_code, RECRUIT.recr_code)		 else RECRUIT.recr_code		 end as recr_code,
		case when ADMISSIONS.saradap_pidm is not null then ADMISSIONS.full_part_ind else RECRUIT.full_part_ind end as full_part_ind,
		case when ADMISSIONS.saradap_pidm is not null then 'A'							 else 'R'						 end as flag	-- shows which record we chose
		into fn_admissions_curricula_dump
	from
	(	-- Admissions Side (saradap)
		select
			dap.saradap_pidm,
			dap.saradap_term_code_entry	as term_code,
			dap.saradap_appl_no				as appl_no,
			dapcur.sorlcur_coll_code		as coll_code,
			dap.saradap_styp_code			as styp_code,
			dap.saradap_levl_code			as levl_code,
			dapcur.sorlcur_camp_code		as camp_code,
			dap.saradap_admt_code			as admt_code,
			dap.saradap_rtyp_code			as rtyp_code,
			dap.saradap_resd_code			as resd_code,
			dapcur.dept_code,
			dapcur.sorlcur_degc_code		as degc_code,
			dapcur.majr_code,
			dapcur.majr2_code,
			dapcur.minr_code,
			dapcur.conc_code,
			dap.saradap_recr_code			as recr_code,
			dap.saradap_full_part_ind		as full_part_ind
		from saradap dap
		left outer join
		(
			--++++++++++++++++++++++++++++++++++++++++++
			-- Select from sorlcur so that we may attain the "primary curricula" record which means
			-- the highest seqno on the lowest priority number in reference to
			--	ADMISSIONS
			--++++++++++++++++++++++++++++++++++++++++++
			select
				asa.*,
				fosMajr.dept_code,
				fosMajr.majr_code,
				fosMaj2.majr2_code,
				fosMinor.minr_code,
				fosConc.conc_code
			from
			(
				select
					asa.sorlcur_pidm,
					asa.sorlcur_term_code,
					asa.sorlcur_coll_code,
					asa.sorlcur_degc_code,
					asa.sorlcur_levl_code,
					asa.sorlcur_camp_code,
					asa.sorlcur_program,
					asa.sorlcur_priority_no,
					asa.sorlcur_key_seqno,
					asa.sorlcur_seqno
				from active_sorlcur_admissions asa	-- active sorlcur records for admissions dept (includes recruit records)
				where asa.sorlcur_lmod_code = 'ADMISSIONS'

			) as asa
			-- sorlfos - MAJOR
			left outer join
			(
				select
					sor.*,
					FullFos.sorlfos_majr_code as majr_code,
					FullFos.sorlfos_dept_code as dept_code
				from
				(
					-- *************************************************
					--	In order to join to sorlfos properly we must do several things...
					--	First:  Select lowest priority inorder to attain primary major
					-- Second: Join this selection back to sorlfos inorder to gain the
					--			  highest/most current seqno with the lowest priority.
					-- This ammounts to attaining the most current/up to date record...
					-- *************************************************
					select seqno.*
						from
						(	-- lowest priority
							select
								sorlfos_pidm,
								sorlfos_term_code,
								sorlfos_lcur_seqno,
								sorlfos_cact_code,
								sorlfos_lfst_code,
								min(sorlfos_priority_no)	as priority_no
							from sorlfos
							where sorlfos_cact_code = 'ACTIVE'
								and sorlfos_lfst_code = 'MAJOR'
							group by
								sorlfos_pidm,
								sorlfos_lcur_seqno,
								sorlfos_term_code,
								sorlfos_cact_code,
								sorlfos_lfst_code
						) as priority
						inner join	-- highest seqno
						(
							select sorlfos_pidm				as pidm,
									 sorlfos_term_code		as term_code,
									 sorlfos_lcur_seqno		as fos_lcur_seqno,
									 sorlfos_priority_no		as fos_priority_no,
									 sorlfos_cact_code		as cact_code,
									 sorlfos_lfst_code		as lfst_code,
									 max(sorlfos_seqno) 		as fos_seqno
							from sorlfos
							group by
								sorlfos_pidm,
								sorlfos_lcur_seqno,
								sorlfos_term_code,
								sorlfos_priority_no,
								sorlfos_cact_code,
								sorlfos_lfst_code
						) as seqno on ( priority.sorlfos_pidm			= seqno.pidm
										and priority.sorlfos_term_code	= seqno.term_code
										and priority.sorlfos_lcur_seqno	= seqno.fos_lcur_seqno
										and priority.priority_no			= seqno.fos_priority_no
										and priority.sorlfos_cact_code	= seqno.cact_code
										and priority.sorlfos_lfst_code	= seqno.lfst_code)
				) as sor	-- full fos to get field we want to compare
				inner join sorlfos FullFos on (sor.pidm				= FullFos.sorlfos_pidm
												and sor.term_code				= FullFos.sorlfos_term_code
												and sor.fos_priority_no		= FullFos.sorlfos_priority_no
												and sor.fos_lcur_seqno		= FullFos.sorlfos_lcur_seqno
												and sor.cact_code				= FullFos.sorlfos_cact_code
												and sor.lfst_code				= FullFos.sorlfos_lfst_code
												and sor.fos_seqno				= FullFos.sorlfos_seqno)
			) as fosMajr on (asa.sorlcur_pidm			= fosMajr.pidm
						and asa.sorlcur_term_code	= fosMajr.term_code
						and asa.sorlcur_seqno	= fosMajr.fos_lcur_seqno)
			-- sorlfos - Major 2
			-- EXPERIMENTAL -- tested slightly, not required for admissions, but left in here
			--		just in case Registration can take advantage of this mess.
			left outer join
			(	-- get the second major, priority_number + 1 on lowest priority (first major)
				select
					curMaj2.*,
					Maj2.*
				from
				(
					select
						maj2.*
					from
					(	-- find people with > 1 major, and select first major priority number
						select
							sorlcur_pidm,
							sorlcur_term_code,
							min(sorlcur_priority_no) as priority_no
						from active_sorlcur_admissions
						where sorlcur_lmod_code = 'ADMISSIONS'
						group by sorlcur_pidm, sorlcur_term_code
						having count(*) > 1
					) as maj1
					inner join
					(	--
						select distinct
							sorlcur_pidm,
							sorlcur_term_code,
							sorlcur_key_seqno,
							sorlcur_seqno,
							sorlcur_priority_no as maj2_priority_no
						from active_sorlcur_admissions
						where sorlcur_lmod_code = 'ADMISSIONS'
					) as maj2 on (maj2.sorlcur_pidm				= maj1.sorlcur_pidm
								and maj2.sorlcur_term_code			= maj1.sorlcur_term_code
								and (maj2.maj2_priority_no - 1)	= maj1.priority_no)
				) as curMaj2
				left outer join
				(
					select
						sor.*,
						FullFos.sorlfos_majr_code as majr2_code
					from
					(
						-- *************************************************
						--	In order to join to sorlfos properly we must do several things...
						--	First:  Select lowest priority inorder to attain primary major
						-- Second: Join this selection back to sorlfos inorder to gain the
						--			  highest/most current seqno with the lowest priority.
						-- This ammounts to attaining the most current/up to date record...
						-- *************************************************
						select seqno.*
							from
							(	-- lowest priority
								select
									sorlfos_pidm,
									sorlfos_term_code,
									sorlfos_lcur_seqno,
									sorlfos_cact_code,
									sorlfos_lfst_code,
									min(sorlfos_priority_no)	as priority_no
								from sorlfos
								where sorlfos_cact_code = 'ACTIVE'
									-- anything other than department, we compare lfst_code, if we are department we
									-- want lfst_code = 'major'
									and sorlfos_lfst_code = 'MAJOR'
								group by
									sorlfos_pidm,
									sorlfos_lcur_seqno,
									sorlfos_term_code,
									sorlfos_cact_code,
									sorlfos_lfst_code
							) as priority
							inner join	-- highest seqno
							(
								select sorlfos_pidm				as pidm,
										 sorlfos_term_code		as term_code,
										 sorlfos_lcur_seqno		as fos_lcur_seqno,
										 sorlfos_priority_no		as fos_priority_no,
										 sorlfos_cact_code		as cact_code,
										 sorlfos_lfst_code		as lfst_code,
										 max(sorlfos_seqno) 		as fos_seqno
								from sorlfos
								group by
									sorlfos_pidm,
									sorlfos_lcur_seqno,
									sorlfos_term_code,
									sorlfos_priority_no,
									sorlfos_cact_code,
									sorlfos_lfst_code
							) as seqno on ( priority.sorlfos_pidm			= seqno.pidm
											and priority.sorlfos_term_code	= seqno.term_code
											and priority.sorlfos_lcur_seqno	= seqno.fos_lcur_seqno
											and priority.priority_no			= seqno.fos_priority_no
											and priority.sorlfos_cact_code	= seqno.cact_code
											and priority.sorlfos_lfst_code	= seqno.lfst_code)
					) as sor	-- full fos to get field we want to compare
					inner join sorlfos FullFos on (sor.pidm				= FullFos.sorlfos_pidm
													and sor.term_code				= FullFos.sorlfos_term_code
													and sor.fos_priority_no		= FullFos.sorlfos_priority_no
													and sor.fos_lcur_seqno		= FullFos.sorlfos_lcur_seqno
													and sor.cact_code				= FullFos.sorlfos_cact_code
													and sor.lfst_code				= FullFos.sorlfos_lfst_code
													and sor.fos_seqno				= FullFos.sorlfos_seqno)
				) as Maj2 on (curMaj2.sorlcur_pidm			= Maj2.pidm
							 and curMaj2.sorlcur_term_code	= Maj2.term_code
							 and curMaj2.sorlcur_seqno			= Maj2.fos_lcur_seqno)
			) as fosMaj2 on (asa.sorlcur_pidm	= fosMaj2.pidm
						and asa.sorlcur_term_code	= fosMaj2.term_code
						and asa.sorlcur_seqno		= fosMaj2.fos_lcur_seqno)
			-- sorlfos - MINOR
			left outer join
			(
				select
					sor.*,
					FullFos.sorlfos_majr_code as minr_code
				from
				(
					-- *************************************************
					--	In order to join to sorlfos properly we must do several things...
					--	First:  Select lowest priority inorder to attain primary major
					-- Second: Join this selection back to sorlfos inorder to gain the
					--			  highest/most current seqno with the lowest priority.
					-- This ammounts to attaining the most current/up to date record...
					-- *************************************************
					select seqno.*
						from
						(	-- lowest priority
							select
								sorlfos_pidm,
								sorlfos_term_code,
								sorlfos_lcur_seqno,
								sorlfos_cact_code,
								sorlfos_lfst_code,
								min(sorlfos_priority_no)	as priority_no
							from sorlfos
							where sorlfos_cact_code = 'ACTIVE'
								and sorlfos_lfst_code = 'MINOR'
							group by
								sorlfos_pidm,
								sorlfos_lcur_seqno,
								sorlfos_term_code,
								sorlfos_cact_code,
								sorlfos_lfst_code
						) as priority
						inner join	-- highest seqno
						(
							select sorlfos_pidm				as pidm,
									 sorlfos_term_code		as term_code,
									 sorlfos_lcur_seqno		as fos_lcur_seqno,
									 sorlfos_priority_no		as fos_priority_no,
									 sorlfos_cact_code		as cact_code,
									 sorlfos_lfst_code		as lfst_code,
									 max(sorlfos_seqno) 		as fos_seqno
							from sorlfos
							group by
								sorlfos_pidm,
								sorlfos_lcur_seqno,
								sorlfos_term_code,
								sorlfos_priority_no,
								sorlfos_cact_code,
								sorlfos_lfst_code
						) as seqno on ( priority.sorlfos_pidm			= seqno.pidm
										and priority.sorlfos_term_code	= seqno.term_code
										and priority.sorlfos_lcur_seqno	= seqno.fos_lcur_seqno
										and priority.priority_no			= seqno.fos_priority_no
										and priority.sorlfos_cact_code	= seqno.cact_code
										and priority.sorlfos_lfst_code	= seqno.lfst_code)
				) as sor	-- full fos to get field we want to compare
				inner join sorlfos FullFos on (sor.pidm				= FullFos.sorlfos_pidm
												and sor.term_code				= FullFos.sorlfos_term_code
												and sor.fos_priority_no		= FullFos.sorlfos_priority_no
												and sor.fos_lcur_seqno		= FullFos.sorlfos_lcur_seqno
												and sor.cact_code				= FullFos.sorlfos_cact_code
												and sor.lfst_code				= FullFos.sorlfos_lfst_code
												and sor.fos_seqno				= FullFos.sorlfos_seqno)
			) as fosMinor on (asa.sorlcur_pidm	= fosMinor.pidm
						and asa.sorlcur_term_code	= fosMinor.term_code
						and asa.sorlcur_seqno		= fosMinor.fos_lcur_seqno)
			-- sorlfos - CONCENTRATION
			left outer join
			(
				select
					sor.*,
					FullFos.sorlfos_majr_code as conc_code
				from
				(
					-- *************************************************
					--	In order to join to sorlfos properly we must do several things...
					--	First:  Select lowest priority inorder to attain primary major
					-- Second: Join this selection back to sorlfos inorder to gain the
					--			  highest/most current seqno with the lowest priority.
					-- This ammounts to attaining the most current/up to date record...
					-- *************************************************
					select seqno.*
						from
						(	-- lowest priority
							select
								sorlfos_pidm,
								sorlfos_term_code,
								sorlfos_lcur_seqno,
								sorlfos_cact_code,
								sorlfos_lfst_code,
								min(sorlfos_priority_no)	as priority_no
							from sorlfos
							where sorlfos_cact_code = 'ACTIVE'
								-- anything other than department, we compare lfst_code, if we are department we
								-- want lfst_code = 'major'
								and sorlfos_lfst_code = 'CONCENTRATION'
							group by
								sorlfos_pidm,
								sorlfos_lcur_seqno,
								sorlfos_term_code,
								sorlfos_cact_code,
								sorlfos_lfst_code
						) as priority
						inner join	-- highest seqno
						(
							select sorlfos_pidm				as pidm,
									 sorlfos_term_code		as term_code,
									 sorlfos_lcur_seqno		as fos_lcur_seqno,
									 sorlfos_priority_no		as fos_priority_no,
									 sorlfos_cact_code		as cact_code,
									 sorlfos_lfst_code		as lfst_code,
									 max(sorlfos_seqno) 		as fos_seqno
							from sorlfos
							group by
								sorlfos_pidm,
								sorlfos_lcur_seqno,
								sorlfos_term_code,
								sorlfos_priority_no,
								sorlfos_cact_code,
								sorlfos_lfst_code
						) as seqno on ( priority.sorlfos_pidm			= seqno.pidm
										and priority.sorlfos_term_code	= seqno.term_code
										and priority.sorlfos_lcur_seqno	= seqno.fos_lcur_seqno
										and priority.priority_no			= seqno.fos_priority_no
										and priority.sorlfos_cact_code	= seqno.cact_code
										and priority.sorlfos_lfst_code	= seqno.lfst_code)
				) as sor	-- full fos to get field we want to compare
				inner join sorlfos FullFos on (sor.pidm				= FullFos.sorlfos_pidm
												and sor.term_code				= FullFos.sorlfos_term_code
												and sor.fos_priority_no		= FullFos.sorlfos_priority_no
												and sor.fos_lcur_seqno		= FullFos.sorlfos_lcur_seqno
												and sor.cact_code				= FullFos.sorlfos_cact_code
												and sor.lfst_code				= FullFos.sorlfos_lfst_code
												and sor.fos_seqno				= FullFos.sorlfos_seqno)
			) as fosConc on (asa.sorlcur_pidm	= fosConc.pidm
						and asa.sorlcur_term_code	= fosConc.term_code
						and asa.sorlcur_seqno		= fosConc.fos_lcur_seqno)
		) as dapcur on (dapcur.sorlcur_pidm			= dap.saradap_pidm
						and dapcur.sorlcur_term_code	= dap.saradap_term_code_entry
						and dapcur.sorlcur_key_seqno	= dap.saradap_appl_no)
	) as ADMISSIONS
----------------------------------------------------------------------------------
-- Recruiting Side (srbrecr)
----------------------------------------------------------------------------------
		right outer join	-- to not loose Recruit records
		(
			select
				srb.srbrecr_pidm,
				srb.srbrecr_term_code			as term_code,
				srb.srbrecr_admin_seqno			as admin_seqno,
				srbcur.sorlcur_coll_code		as coll_code,
				srb.srbrecr_styp_code			as styp_code,
				srb.srbrecr_levl_code			as levl_code,
				srbcur.sorlcur_camp_code		as camp_code,
				srb.srbrecr_admt_code			as admt_code,
				srb.srbrecr_rtyp_code			as rtyp_code,
				srb.srbrecr_resd_code			as resd_code,
				srbcur.dept_code,
				srbcur.sorlcur_degc_code		as degc_code,
				srbcur.majr_code,
				srbcur.majr2_code,
				srbcur.minr_code,
				srbcur.conc_code,
				srb.srbrecr_recr_code			as recr_code,
				srb.srbrecr_full_part_ind		as full_part_ind
			from srbrecr srb
			left outer join
			(
				--++++++++++++++++++++++++++++++++++++++++++
				-- Select from sorlcur so that we may attain the "primary curricula" record which means
				-- the highest seqno on the lowest priority number in reference to
				--	RECRUIT
				--++++++++++++++++++++++++++++++++++++++++++
			select
				asa.*,
				fosMajr.dept_code,
				fosMajr.majr_code,
				fosMaj2.majr2_code,
				fosMinor.minr_code,
				fosConc.conc_code
			from
			(
				select
					asa.sorlcur_pidm,
					asa.sorlcur_term_code,
					asa.sorlcur_coll_code,
					asa.sorlcur_degc_code,
					asa.sorlcur_levl_code,
					asa.sorlcur_camp_code,
					asa.sorlcur_program,
					asa.sorlcur_priority_no,
					asa.sorlcur_key_seqno,
					asa.sorlcur_seqno
				from active_sorlcur_admissions asa	-- active sorlcur records for admissions dept (includes recruit records)
				where asa.sorlcur_lmod_code = 'RECRUIT'

			) as asa
			-- sorlfos - MAJOR
			left outer join
			(
				select
					sor.*,
					FullFos.sorlfos_majr_code as majr_code,
					FullFos.sorlfos_dept_code as dept_code
				from
				(
					-- *************************************************
					--	In order to join to sorlfos properly we must do several things...
					--	First:  Select lowest priority inorder to attain primary major
					-- Second: Join this selection back to sorlfos inorder to gain the
					--			  highest/most current seqno with the lowest priority.
					-- This ammounts to attaining the most current/up to date record...
					-- *************************************************
					select seqno.*
						from
						(	-- lowest priority
							select
								sorlfos_pidm,
								sorlfos_term_code,
								sorlfos_lcur_seqno,
								sorlfos_cact_code,
								sorlfos_lfst_code,
								min(sorlfos_priority_no)	as priority_no
							from sorlfos
							where sorlfos_cact_code = 'ACTIVE'
								and sorlfos_lfst_code = 'MAJOR'
							group by
								sorlfos_pidm,
								sorlfos_lcur_seqno,
								sorlfos_term_code,
								sorlfos_cact_code,
								sorlfos_lfst_code
						) as priority
						inner join	-- highest seqno
						(
							select sorlfos_pidm				as pidm,
									 sorlfos_term_code		as term_code,
									 sorlfos_lcur_seqno		as fos_lcur_seqno,
									 sorlfos_priority_no		as fos_priority_no,
									 sorlfos_cact_code		as cact_code,
									 sorlfos_lfst_code		as lfst_code,
									 max(sorlfos_seqno) 		as fos_seqno
							from sorlfos
							group by
								sorlfos_pidm,
								sorlfos_lcur_seqno,
								sorlfos_term_code,
								sorlfos_priority_no,
								sorlfos_cact_code,
								sorlfos_lfst_code
						) as seqno on ( priority.sorlfos_pidm			= seqno.pidm
										and priority.sorlfos_term_code	= seqno.term_code
										and priority.sorlfos_lcur_seqno	= seqno.fos_lcur_seqno
										and priority.priority_no			= seqno.fos_priority_no
										and priority.sorlfos_cact_code	= seqno.cact_code
										and priority.sorlfos_lfst_code	= seqno.lfst_code)
				) as sor	-- full fos to get field we want to compare
				inner join sorlfos FullFos on (sor.pidm				= FullFos.sorlfos_pidm
												and sor.term_code				= FullFos.sorlfos_term_code
												and sor.fos_priority_no		= FullFos.sorlfos_priority_no
												and sor.fos_lcur_seqno		= FullFos.sorlfos_lcur_seqno
												and sor.cact_code				= FullFos.sorlfos_cact_code
												and sor.lfst_code				= FullFos.sorlfos_lfst_code
												and sor.fos_seqno				= FullFos.sorlfos_seqno)
			) as fosMajr on (asa.sorlcur_pidm			= fosMajr.pidm
						and asa.sorlcur_term_code	= fosMajr.term_code
						and asa.sorlcur_seqno	= fosMajr.fos_lcur_seqno)
			-- sorlfos - Major 2
			-- EXPERIMENTAL -- tested slightly, not required for admissions, but left in here
			--		just in case Registration can take advantage of this mess.
			left outer join
			(	-- get the second major, priority_number + 1 on lowest priority (first major)
				select
					curMaj2.*,
					Maj2.*
				from
				(
					select
						maj2.*
					from
					(	-- find people with > 1 major, and select first major priority number
						select
							sorlcur_pidm,
							sorlcur_term_code,
							min(sorlcur_priority_no) as priority_no
						from active_sorlcur_admissions
						where sorlcur_lmod_code = 'RECRUIT'
						group by sorlcur_pidm, sorlcur_term_code
						having count(*) > 1
					) as maj1
					inner join
					(	--
						select distinct
							sorlcur_pidm,
							sorlcur_term_code,
							sorlcur_key_seqno,
							sorlcur_seqno,
							sorlcur_priority_no as maj2_priority_no
						from active_sorlcur_admissions
						where sorlcur_lmod_code = 'RECRUIT'
					) as maj2 on (maj2.sorlcur_pidm				= maj1.sorlcur_pidm
								and maj2.sorlcur_term_code			= maj1.sorlcur_term_code
								and (maj2.maj2_priority_no - 1)	= maj1.priority_no)
				) as curMaj2
				left outer join
				(
					select
						sor.*,
						FullFos.sorlfos_majr_code as majr2_code
					from
					(
						-- *************************************************
						--	In order to join to sorlfos properly we must do several things...
						--	First:  Select lowest priority inorder to attain primary major
						-- Second: Join this selection back to sorlfos inorder to gain the
						--			  highest/most current seqno with the lowest priority.
						-- This ammounts to attaining the most current/up to date record...
						-- *************************************************
						select seqno.*
							from
							(	-- lowest priority
								select
									sorlfos_pidm,
									sorlfos_term_code,
									sorlfos_lcur_seqno,
									sorlfos_cact_code,
									sorlfos_lfst_code,
									min(sorlfos_priority_no)	as priority_no
								from sorlfos
								where sorlfos_cact_code = 'ACTIVE'
									-- anything other than department, we compare lfst_code, if we are department we
									-- want lfst_code = 'major'
									and sorlfos_lfst_code = 'MAJOR'
								group by
									sorlfos_pidm,
									sorlfos_lcur_seqno,
									sorlfos_term_code,
									sorlfos_cact_code,
									sorlfos_lfst_code
							) as priority
							inner join	-- highest seqno
							(
								select sorlfos_pidm				as pidm,
										 sorlfos_term_code		as term_code,
										 sorlfos_lcur_seqno		as fos_lcur_seqno,
										 sorlfos_priority_no		as fos_priority_no,
										 sorlfos_cact_code		as cact_code,
										 sorlfos_lfst_code		as lfst_code,
										 max(sorlfos_seqno) 		as fos_seqno
								from sorlfos
								group by
									sorlfos_pidm,
									sorlfos_lcur_seqno,
									sorlfos_term_code,
									sorlfos_priority_no,
									sorlfos_cact_code,
									sorlfos_lfst_code
							) as seqno on ( priority.sorlfos_pidm			= seqno.pidm
											and priority.sorlfos_term_code	= seqno.term_code
											and priority.sorlfos_lcur_seqno	= seqno.fos_lcur_seqno
											and priority.priority_no			= seqno.fos_priority_no
											and priority.sorlfos_cact_code	= seqno.cact_code
											and priority.sorlfos_lfst_code	= seqno.lfst_code)
					) as sor	-- full fos to get field we want to compare
					inner join sorlfos FullFos on (sor.pidm				= FullFos.sorlfos_pidm
													and sor.term_code				= FullFos.sorlfos_term_code
													and sor.fos_priority_no		= FullFos.sorlfos_priority_no
													and sor.fos_lcur_seqno		= FullFos.sorlfos_lcur_seqno
													and sor.cact_code				= FullFos.sorlfos_cact_code
													and sor.lfst_code				= FullFos.sorlfos_lfst_code
													and sor.fos_seqno				= FullFos.sorlfos_seqno)
				) as Maj2 on (curMaj2.sorlcur_pidm			= Maj2.pidm
							 and curMaj2.sorlcur_term_code	= Maj2.term_code
							 and curMaj2.sorlcur_seqno			= Maj2.fos_lcur_seqno)
			) as fosMaj2 on (asa.sorlcur_pidm	= fosMaj2.pidm
						and asa.sorlcur_term_code	= fosMaj2.term_code
						and asa.sorlcur_seqno		= fosMaj2.fos_lcur_seqno)
			-- sorlfos - MINOR
			left outer join
			(
				select
					sor.*,
					FullFos.sorlfos_majr_code as minr_code
				from
				(
					-- *************************************************
					--	In order to join to sorlfos properly we must do several things...
					--	First:  Select lowest priority inorder to attain primary major
					-- Second: Join this selection back to sorlfos inorder to gain the
					--			  highest/most current seqno with the lowest priority.
					-- This ammounts to attaining the most current/up to date record...
					-- *************************************************
					select seqno.*
						from
						(	-- lowest priority
							select
								sorlfos_pidm,
								sorlfos_term_code,
								sorlfos_lcur_seqno,
								sorlfos_cact_code,
								sorlfos_lfst_code,
								min(sorlfos_priority_no)	as priority_no
							from sorlfos
							where sorlfos_cact_code = 'ACTIVE'
								and sorlfos_lfst_code = 'MINOR'
							group by
								sorlfos_pidm,
								sorlfos_lcur_seqno,
								sorlfos_term_code,
								sorlfos_cact_code,
								sorlfos_lfst_code
						) as priority
						inner join	-- highest seqno
						(
							select sorlfos_pidm				as pidm,
									 sorlfos_term_code		as term_code,
									 sorlfos_lcur_seqno		as fos_lcur_seqno,
									 sorlfos_priority_no		as fos_priority_no,
									 sorlfos_cact_code		as cact_code,
									 sorlfos_lfst_code		as lfst_code,
									 max(sorlfos_seqno) 		as fos_seqno
							from sorlfos
							group by
								sorlfos_pidm,
								sorlfos_lcur_seqno,
								sorlfos_term_code,
								sorlfos_priority_no,
								sorlfos_cact_code,
								sorlfos_lfst_code
						) as seqno on ( priority.sorlfos_pidm			= seqno.pidm
										and priority.sorlfos_term_code	= seqno.term_code
										and priority.sorlfos_lcur_seqno	= seqno.fos_lcur_seqno
										and priority.priority_no			= seqno.fos_priority_no
										and priority.sorlfos_cact_code	= seqno.cact_code
										and priority.sorlfos_lfst_code	= seqno.lfst_code)
				) as sor	-- full fos to get field we want to compare
				inner join sorlfos FullFos on (sor.pidm				= FullFos.sorlfos_pidm
												and sor.term_code				= FullFos.sorlfos_term_code
												and sor.fos_priority_no		= FullFos.sorlfos_priority_no
												and sor.fos_lcur_seqno		= FullFos.sorlfos_lcur_seqno
												and sor.cact_code				= FullFos.sorlfos_cact_code
												and sor.lfst_code				= FullFos.sorlfos_lfst_code
												and sor.fos_seqno				= FullFos.sorlfos_seqno)
			) as fosMinor on (asa.sorlcur_pidm	= fosMinor.pidm
						and asa.sorlcur_term_code	= fosMinor.term_code
						and asa.sorlcur_seqno		= fosMinor.fos_lcur_seqno)
			-- sorlfos - CONCENTRATION
			left outer join
			(
				select
					sor.*,
					FullFos.sorlfos_majr_code as conc_code
				from
				(
					-- *************************************************
					--	In order to join to sorlfos properly we must do several things...
					--	First:  Select lowest priority inorder to attain primary major
					-- Second: Join this selection back to sorlfos inorder to gain the
					--			  highest/most current seqno with the lowest priority.
					-- This ammounts to attaining the most current/up to date record...
					-- *************************************************
					select seqno.*
						from
						(	-- lowest priority
							select
								sorlfos_pidm,
								sorlfos_term_code,
								sorlfos_lcur_seqno,
								sorlfos_cact_code,
								sorlfos_lfst_code,
								min(sorlfos_priority_no)	as priority_no
							from sorlfos
							where sorlfos_cact_code = 'ACTIVE'
								-- anything other than department, we compare lfst_code, if we are department we
								-- want lfst_code = 'major'
								and sorlfos_lfst_code = 'CONCENTRATION'
							group by
								sorlfos_pidm,
								sorlfos_lcur_seqno,
								sorlfos_term_code,
								sorlfos_cact_code,
								sorlfos_lfst_code
						) as priority
						inner join	-- highest seqno
						(
							select sorlfos_pidm				as pidm,
									 sorlfos_term_code		as term_code,
									 sorlfos_lcur_seqno		as fos_lcur_seqno,
									 sorlfos_priority_no		as fos_priority_no,
									 sorlfos_cact_code		as cact_code,
									 sorlfos_lfst_code		as lfst_code,
									 max(sorlfos_seqno) 		as fos_seqno
							from sorlfos
							group by
								sorlfos_pidm,
								sorlfos_lcur_seqno,
								sorlfos_term_code,
								sorlfos_priority_no,
								sorlfos_cact_code,
								sorlfos_lfst_code
						) as seqno on ( priority.sorlfos_pidm			= seqno.pidm
										and priority.sorlfos_term_code	= seqno.term_code
										and priority.sorlfos_lcur_seqno	= seqno.fos_lcur_seqno
										and priority.priority_no			= seqno.fos_priority_no
										and priority.sorlfos_cact_code	= seqno.cact_code
										and priority.sorlfos_lfst_code	= seqno.lfst_code)
				) as sor	-- full fos to get field we want to compare
				inner join sorlfos FullFos on (sor.pidm				= FullFos.sorlfos_pidm
												and sor.term_code				= FullFos.sorlfos_term_code
												and sor.fos_priority_no		= FullFos.sorlfos_priority_no
												and sor.fos_lcur_seqno		= FullFos.sorlfos_lcur_seqno
												and sor.cact_code				= FullFos.sorlfos_cact_code
												and sor.lfst_code				= FullFos.sorlfos_lfst_code
												and sor.fos_seqno				= FullFos.sorlfos_seqno)
			) as fosConc on (asa.sorlcur_pidm	= fosConc.pidm
						and asa.sorlcur_term_code	= fosConc.term_code
						and asa.sorlcur_seqno		= fosConc.fos_lcur_seqno)
		) as srbcur on (srbcur.sorlcur_pidm			= srb.srbrecr_pidm
						and srbcur.sorlcur_term_code	= srb.srbrecr_term_code
						and srbcur.sorlcur_key_seqno	= srb.srbrecr_admin_seqno)
	) as RECRUIT on (RECRUIT.srbrecr_pidm	= ADMISSIONS.saradap_pidm
					 and RECRUIT.term_code		= ADMISSIONS.term_code
					 and RECRUIT.coll_code		= ADMISSIONS.coll_code
					 and RECRUIT.styp_code		= ADMISSIONS.styp_code
					 and RECRUIT.levl_code		= ADMISSIONS.levl_code)

exec config..sp_create_index 'fn_admissions_curricula_dump', 'stage'
